%{!?perl_vendorarch:%global perl_vendorarch %(eval "`perl -V:installvendorarch`"; echo $installvendorarch)}

%global __provides_exclude_from ^(%{perl_vendorarch}/auto|%{python3_sitearch})/.*\\.so$

Name: openbabel
Version: 3.1.1
Release:    1%{?dist}
Summary: Chemistry software file format converter
License: GPL-2.0-only
URL: https://openbabel.org/
Source0: https://github.com/openbabel/openbabel/archive/openbabel-openbabel-%(echo %{version} | tr '.' '-').tar.gz
Source1: obgui.desktop
Source2: openbabel-inchi-license-lgpl-2.1.txt

Patch0: %{name}-perl.patch

Patch1: %{name}-plugindir.patch

Patch2: %{name}-noswig-rubymethod.patch

Patch3: %{name}-ruby19-vendorarch.patch

Patch4: %{name}-disable-tests.patch

Patch5: %{name}-fix-libdir-in-pkgconfig.patch

Patch6: %{name}-disable-tests-s390x.patch

Patch7: %{name}-3.1.1-fix_bug2223.patch
Patch8: %{name}-3.1.1-fix_bug2217.patch
Patch9: %{name}-3.1.1-bug2378.patch
Patch10: %{name}-3.1.1-bug2493.patch

BuildRequires: make
BuildRequires: boost-devel
BuildRequires: swig
BuildRequires: cmake3
BuildRequires: dos2unix
BuildRequires: desktop-file-utils
BuildRequires: eigen3-devel
BuildRequires: gcc-c++
BuildRequires: inchi-devel >= 1.0.3
BuildRequires: wxGTK-devel
BuildRequires: libxml2-devel
BuildRequires: ImageMagick
BuildRequires: rapidjson-devel
Requires:      %{name}-libs = %{version}-%{release}

%description
Open Babel is a free, open-source version of the Babel chemistry file
translation program. Open Babel is a project designed to pick up where
Babel left off, as a cross-platform program and library designed to
interconvert between many file formats used in molecular modeling,
computational chemistry, and many related areas.

This package contains the command-line utility, which is intended to
be used as a replacement for the original babel program, to translate
between various chemical file formats as well as a wide variety of
utilities to foster development of other open source scientific
software.

%package devel
Summary: Development tools for programs which will use the Open Babel library
Requires: %{name}-libs = %{version}-%{release}

%description devel
The %{name}-devel package includes the header files and libraries
necessary for developing programs using the Open Babel library.

%package doc
Summary: Additional documentation for the Open Babel library
BuildArch: noarch

%description doc
This package contains additional documentation for Open Babel.

%package gui
Summary: Chemistry software file format converter - GUI version
Requires: %{name}-libs = %{version}-%{release}

%description gui
Open Babel is a free, open-source version of the Babel chemistry file
translation program. Open Babel is a project designed to pick up where
Babel left off, as a cross-platform program and library designed to
interconvert between many file formats used in molecular modeling,
computational chemistry, and many related areas.

This package contains the graphical interface.

%package libs
Summary: Chemistry software file format converter - libraries

%description libs
Open Babel is a free, open-source version of the Babel chemistry file
translation program. Open Babel is a project designed to pick up where
Babel left off, as a cross-platform program and library designed to
interconvert between many file formats used in molecular modeling,
computational chemistry, and many related areas.

This package contains the C++ library, which includes all of the
file-translation code.

%package -n perl-%{name}
Summary: Perl wrapper for the Open Babel library
Requires: %{name}-libs = %{version}-%{release}
BuildRequires: perl-devel
BuildRequires: perl-generators

%description -n perl-%{name}
Perl wrapper for the Open Babel library.

%package -n python3-%{name}
Summary: Python wrapper for the Open Babel library
Requires: %{name}-libs = %{version}-%{release}
BuildRequires: python3-devel
BuildRequires: python3-setuptools
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
Python3 wrapper for the Open Babel library.

%package -n ruby-%{name}
Summary: Ruby wrapper for the Open Babel library
Requires: ruby(release)
Requires: %{name}-libs = %{version}-%{release}
BuildRequires: ruby-devel

%description -n ruby-%{name}
Ruby wrapper for the Open Babel library.

%prep
%setup -q -n %{name}-%{name}-%(echo %{version} | tr '.' '-')
%patch0 -p1 -b .perl_path
%patch1 -p1 -b .plugindir
%patch2 -p1 -b .noswig_ruby
%patch3 -p1 -b .ruby_vendor
%ifarch aarch64
%patch4 -p1 -b .tests
%endif
%patch5 -p1 -b .s390x
%patch7 -p1 -b .backup
%patch8 -p1 -b .backup
%patch9 -p1 -b .backup
%patch10 -p1 -b .backup

rm -rf src/formats/libinchi

dos2unix -k \
  data/chemdrawcdx.h \
  include/openbabel/{tautomer.h,math/align.h} \
  src/math/align.cpp \
  test/testsmartssym.py \

convert src/GUI/babel.xpm -transparent white babel.png

pushd doc
for man in *.1; do
 html=`basename $man .1`.html
 if [ -f $html ]; then
   rm $html
 fi
done
popd

%build
mkdir -p %{_target_platform}
%cmake3 -B %{_target_platform} \
 -Wno-dev \
 -DCMAKE_SKIP_RPATH:BOOL=ON \
 -DBUILD_GUI:BOOL=ON \
 -DPYTHON_BINDINGS:BOOL=ON \
 -DPYTHON_EXECUTABLE=%{__python3} \
 -DPERL_BINDINGS:BOOL=ON \
 -DRUBY_BINDINGS:BOOL=ON \
 -DWITH_MAEPARSER:BOOL=OFF \
 -DWITH_COORDGEN:BOOL=OFF \
 -DOB_PLUGIN_INSTALL_DIR:PATH=%{_lib}/openbabel3 \
 -DOPENBABEL_USE_SYSTEM_INCHI=true \
 -DENABLE_VERSIONED_FORMATS=false \
 -DRUN_SWIG=true \
 -DENABLE_TESTS:BOOL=ON \
 -DOPTIMIZE_NATIVE=OFF \
 -DGLIBC_24_COMPATIBLE:BOOL=OFF \

%make_build -C %{_target_platform}

%install
%make_install -C %{_target_platform}

rm -f %{buildroot}%{_libdir}/cmake/openbabel2/*.cmake

desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE1}
install -Dpm644 babel.png %{buildroot}%{_datadir}/pixmaps/babel.png

mkdir -p %{buildroot}%{_sysconfdir}/profile.d
cat > %{buildroot}%{_sysconfdir}/profile.d/openbabel3.sh <<EOF
BABEL_LIBDIR=%{_libdir}/%{name}3
export BABEL_LIBDIR
BABEL_DATADIR=%{_datadir}/%{name}
export BABEL_DATADIR
EOF
cat > %{buildroot}%{_sysconfdir}/profile.d/openbabel3.csh <<EOF
setenv BABEL_LIBDIR %{_libdir}/%{name}3
setenv BABEL_DATADIR %{_datadir}/%{name}
EOF

%if 1
%check
%define _vpath_builddir %{_target_platform}
pushd %{_vpath_builddir}

rm -f %{_lib}/openbabel.so

export CTEST_OUTPUT_ON_FAILURE=1
export PYTHONPATH=%{buildroot}%{python3_sitearch}
%ifarch aarch64 %{arm} %{power64} s390x
ctest3 -j1 --force-new-ctest-process -E 'pybindtest_bindings|pybindtest_obconv_writers'
%else
ctest3 -j1 --force-new-ctest-process
%endif
%endif

%files
%config(noreplace) %{_sysconfdir}/profile.d/openbabel3.sh
%config(noreplace) %{_sysconfdir}/profile.d/openbabel3.csh
%{_bindir}/ob*
%{_bindir}/roundtrip
%{_mandir}/man1/*.1*
%exclude %{_bindir}/obgui
%exclude %{_mandir}/man1/obgui.1*

%files devel
%{_includedir}/%{name}3/
%{_libdir}/libopenbabel.so
%{_libdir}/libopenbabel.so.7
%{_libdir}/pkgconfig/openbabel-3.pc
%{_libdir}/cmake/openbabel3/

%files doc
%doc doc/*.html doc/README* doc/dioxin.*

%files gui
%{_bindir}/obgui
%{_datadir}/applications/obgui.desktop
%{_datadir}/pixmaps/babel.png
%{_mandir}/man1/obgui.1*

%files libs
%license COPYING
%doc THANKS AUTHORS authors.txt README.md
%{_datadir}/%{name}/
%{_libdir}/%{name}3/
%{_libdir}/libopenbabel.so.7.0.0

%files -n perl-%{name}
%{perl_vendorarch}/Chemistry/OpenBabel.pm
%dir %{perl_vendorarch}/*/Chemistry/OpenBabel
%{perl_vendorarch}/*/Chemistry/OpenBabel/OpenBabel.so

%files -n python3-%{name}
%{python3_sitearch}/openbabel/

%files -n ruby-%{name}
%{ruby_vendorarchdir}/openbabel.so

%changelog
* Mon Aug 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.1.1-1
- initial build
